@@ -65,7 +65,7 @@ NNS.boost <- function(IVs.train,
 
   if(is.null(obj.fn)) stop("Please provide an objective function")
 
-  if(tolower(type) == "class" && min(as.numeric(DV.train))==0) warning("Base response variable category should be 1, not 0.")
+  if(!is.null(type) && min(as.numeric(DV.train))==0) warning("Base response variable category should be 1, not 0.")
 
 
   if(any(class(IVs.train)=="tbl")) IVs.train <- as.data.frame(IVs.train)
