@@ -41,12 +41,7 @@ NNS.M.reg <- function (X_n, Y, factor.2.dummy = TRUE, order = NULL, stn = NULL,
 
   ###  Regression Point Matrix
   if(is.numeric(order) || is.null(order)){
-    if(is.null(order)){
-        dependence <- NNS.dep.hd(original.matrix)$Dependence
-        order <- max(ceiling(log(length(original.DV), 10)), ceiling(ceiling(log(length(original.DV),2)) * dependence))
-    }
-
-    reg.points <- apply(original.IVs, 2, function(b) NNS.reg(b, original.DV, factor.2.dummy = factor.2.dummy, order = order, stn = stn, type = type, noise.reduction = noise.reduction, plot = FALSE, multivariate.call = TRUE)$x)
+    reg.points <- apply(original.IVs, 2, function(b) NNS.reg(b, original.DV, factor.2.dummy = factor.2.dummy, order = order, stn = stn, type = type, noise.reduction = noise.reduction, plot = FALSE, multivariate.call = TRUE, ncores = 1)$x)
 
     if(length(unique(sapply(reg.points, length))) != 1){
       reg.points.matrix <- do.call('cbind', lapply(reg.points, `length<-`, max(lengths(reg.points))))
@@ -92,23 +87,20 @@ NNS.M.reg <- function (X_n, Y, factor.2.dummy = TRUE, order = NULL, stn = NULL,
 
   ### PARALLEL
 
-  if (is.null(ncores)) {
-    num_cores <- as.integer(detectCores()) - 1
+  if(is.null(ncores)) {
+    num_cores <- as.integer(parallel::detectCores()) - 1
   } else {
     num_cores <- ncores
   }
 
-  if(num_cores>1){
-    cl <- makeCluster(num_cores)
-    registerDoParallel(cl)
-  } else { cl <- NULL }
-
-  if(is.null(cl)){
+  if(num_cores<=1){
       for(j in 1:n){
           sorted.reg.points <- na.omit(sort(reg.points.matrix[ , j]))
           NNS.ID[[j]] <- findInterval(original.IVs[ , j], vec = sorted.reg.points, left.open = FALSE)
       }
   } else {
+      cl <- parallel::makeCluster(num_cores)
+      doParallel::registerDoParallel(cl)
       NNS.ID <- foreach(j = 1:n)%dopar%{
           sorted.reg.points <- na.omit(sort(reg.points.matrix[ , j]))
           return(findInterval(original.IVs[ , j], vec = sorted.reg.points, left.open = FALSE))
@@ -186,7 +178,7 @@ NNS.M.reg <- function (X_n, Y, factor.2.dummy = TRUE, order = NULL, stn = NULL,
 
   if(n.best > 1 && !point.only){
     RPM <- (REGRESSION.POINT.MATRIX)
-    if(!is.null(cl)){
+    if(num_cores>1){
         fitted.matrix$y.hat <- parallel::parApply(cl, original.IVs, 1, function(z) NNS::NNS.distance(RPM, dist.estimate = z, type = dist, k = n.best)[1])
     } else {
         fits <- data.table::data.table(original.IVs)
@@ -242,25 +234,19 @@ NNS.M.reg <- function (X_n, Y, factor.2.dummy = TRUE, order = NULL, stn = NULL,
     }
 
     if(!is.null(np)){
-
-
       lows <- logical()
       highs <- logical()
       outsiders <- numeric()
       DISTANCES <- list()
 
-
-
-
       distances <- data.table::data.table(point.est)
 
-      if(!is.null(cl)){
+      if(num_cores>1){
         DISTANCES <- parallel::parApply(cl, distances, 1, function(z) NNS::NNS.distance(REGRESSION.POINT.MATRIX, dist.estimate = z, type = dist, k = n.best)[1])
 
-        stopCluster(cl)
+        parallel::stopCluster(cl)
         registerDoSEQ()
       } else {
-
         distances <- distances[, DISTANCES :=  NNS.distance(REGRESSION.POINT.MATRIX, dist.estimate = .SD, type = dist, k = n.best)[1], by = 1:nrow(point.est)]
 
         DISTANCES <- as.numeric(unlist(distances$DISTANCES))
