@@ -89,7 +89,7 @@ NNS.stack <- function(IVs.train,
 
   if(is.null(obj.fn)) stop("Please provide an objective function")
 
-  if(tolower(type) == "class" && min(as.numeric(DV.train))==0) warning("Base response variable category should be 1, not 0.")
+  if(!is.null(type) && min(as.numeric(DV.train))==0) warning("Base response variable category should be 1, not 0.")
 
   if(any(class(IVs.train)=="tbl")) IVs.train <- as.data.frame(IVs.train)
   if(any(class(DV.train)=="tbl")) DV.train <- as.vector(unlist(DV.train))
