@@ -48,7 +48,7 @@ Uni.caus <- function(x, y, tau, plot = TRUE){
 
 
   ## Correlation of Normalized Variables
-  rho.x.y <- NNS.dep(x.norm.to.y, y.norm.to.x)$Correlation
+  rho.x.y <- NNS.dep(y.norm.to.x, x.norm.to.y, asym = TRUE)$Dependence
 
   Causation.x.given.y <- P.x.given.y * rho.x.y
 
